/***************************** C HEADER FILE *********************************
**
**  Project:    RTCU Option Key Server, Client library
**  Filename:   OKSPROT.H
**  Version:    1.00
**  Date:       February 9, 2012
**  
*****************************************************************************/
#ifndef _LIBOKSCLIENT__H_
#define _LIBOKSCLIENT__H_

#ifdef __cplusplus
extern "C" {
#endif


/*****************************************************************************
**
**    MODULES USED 
**
*****************************************************************************/


/*****************************************************************************
**
**    DEFINITIONS AND MACROS
**
*****************************************************************************/


/****************************************************************************
**
**    TYPEDEFS AND STRUCTURES
**
****************************************************************************/


/****************************************************************************
** 
**    EXPORTED VARIABLES
**
****************************************************************************/


/****************************************************************************
**
**    EXPORTED FUNCTIONS
**
****************************************************************************/

/////////////////////////////////////////////////////////////////////////////
// This will open a connection to the Option Key Server.
//
// Input:
//    username   - Zero terminated ASCII string with the username.
//    password   - Zero terminated ASCII string with the password.
//
// Output:
//    None.
//
// Returns:
//    0          - Success.
//    1          - Already open.
//    2          - General error.
//    3          - Connection error.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksConnect(char *username, char *password);

/////////////////////////////////////////////////////////////////////////////
// This will close an open connection to the Option Key Server.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    None.
//
/////////////////////////////////////////////////////////////////////////////
void _stdcall oksDisconnect(void);

/////////////////////////////////////////////////////////////////////////////
// This will return the status of the connection.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    0          - Not connected.
//    1          - Opening connection.
//    2          - Authenticating.
//    3          - Connected.
//    4          - Closing connecting.
//    5          - Could not connect to server.
//    6          - Network error.
//    7          - Wrong user or password.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksStatus(void);

/////////////////////////////////////////////////////////////////////////////
// This will return the version of the OKS sytem.
//
// Input:
//    index      - 0 (zero) = Client version, 1 = Server version.
//
// Output:
//    None.
//
// Returns:
//    Version of the OKS system scaled by 100.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksVersion(int index);

/////////////////////////////////////////////////////////////////////////////
// This will return the number of credits available.
//
// Input:
//    None.
//
// Output:
//    None.
//
// Returns:
//    Number of credits
//    -1         - Not connected to OKS server
//    -2         - Timeout waiting for reply.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksGetCredits(void);

/////////////////////////////////////////////////////////////////////////////
// This will read the available options from the server.
//
// Input:
//    target     - The type of unit to get the list of available options for.
//                 zero = Get a list of all available options.
//                 The unit type is identified by the first three digits in
//                 the short format serial-number.
//
// Output:
//    None.
//
// Returns:
//    0          - Success.
//    -1         - Not connected to server
//    -2         - Timeout waiting for reply.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksOptionsUpdate(int target = 0);

/////////////////////////////////////////////////////////////////////////////
// This will return the information of an option.
//
// Input:
//    index      - The zero based index of the option to retrieve.
//    max_desc   - The maximum length of the option description.
//                 (The zero terminator is included)
//
// Output:
//    id         - Pointer to buffer where the option ID string is stored.
//    price      - Pointer to buffer where the option price is stored.
//    desc       - Pointer to buffer where the option description string is stored.
//
// Returns:
//    1          - No option with this index.
//    0          - Success.
//    -1         - Not connected to server
//    -2         - Timeout waiting for reply.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksOptionsGet(int  index,
                           char id[6],
                           int  *price,
                           char *desc,
                           int  max_desc);

/////////////////////////////////////////////////////////////////////////////
// This will order on option key from the server.
//
// Input:
//    serial     - The serial number of the unit to order for.
//    options    - Zero terminated ASCII string containing the ID's of the
//                 options to order. The ID's must be seperated by a space
//                 character (ASCII 32).
//
// Output:
//    key        - Pointer to buffer where the option key is stored.
//                 The option key is a 11 character long ASCII string with
//                 a zero terminator.
//    cost       - The number of credits used for options.
//
// Returns:
//    4          - Restricted option requested.
//    3          - Not enough credits for options.
//    2          - Invalid option requested.
//    1          - General error.
//    0          - Success.
//    -1         - Not connected to server
//    -2         - Timeout waiting for reply.
//
/////////////////////////////////////////////////////////////////////////////
int _stdcall oksOrder(long serial, char *options, char key[12], int *cost);


#ifdef __cplusplus
}
#endif

#endif  /*_LIBOKSCLIENT__H_*/
/****************************************************************************
**
**    EOF 
**
****************************************************************************/
